@@ -25,7 +25,7 @@ class FeatureSelector():
         self.__label_encoder = LabelEncoder()
         self.__data_copy = data_type_identifier.keep_initial_data_types(data.copy(deep=True))
         self.__predictions = data_type_identifier.predict(data, verbose=0) 
-        cat_check = self.__predictions.values == const.CATEGORICAL
+        cat_check = self.__predictions.values==const.CATEGORICAL
         num_check = self.__predictions.values==const.NUMERICAL
         self.__categorical_variable_names = self.__predictions[cat_check].index
         self.__numerical_variable_names = self.__predictions[num_check].index
@@ -153,7 +153,31 @@ class FeatureSelector():
             return precedent_out_of_bag_score
         return 1
        
-     
+    def get_predicted_features(self):
+        """
+        Returns
+        -------
+        TYPE
+            DESCRIPTION.
+
+        """
+        return self.__predictions
+    
+    def set_predicted_features(self, features_prediction):
+        """
+
+        Parameters
+        ----------
+        features_prediction : TYPE
+            DESCRIPTION.
+
+        Returns
+        -------
+        None.
+
+        """
+        self.__predictions = features_prediction
+        
     def corr_coef(self, X, Y):
         """
         Parameters
